==> tetzle_2.2.3.orig.tar.gz: tetzle-2.2.3/translations/tetzle_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Atverti paveikslą</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Išvaizda</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Parinktys</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Nuožulnūs kraštai</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Mesti šešėlius</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Spalvos</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fonas:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Šešėlis</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Paryškinimas:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Trūksta paveikslo.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Prašome palaukti</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Įkeliamas paveikslas...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Kuriama dėlionė...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Kuriamos dalys...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Įkeliama dėlionė...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Nežinomas duomenų formatas</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Nežinomas elementas &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>XML failo analizės klaida.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Įkeliamos dalys...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Gaunamos dalys...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Talpinamos dalys...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sėkmė</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Pasirinkite žaidimą</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Dabartiniai žaidimai</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Naujas žaidimas</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Paveikslo savybės</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Žymės:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalbą:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos kalba&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Pridėti paveikslą</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Pašalinti paveikslą</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Paveikslo savybės</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 dalių</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Kopijuojami paveikslai...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atšaukti</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Šalinti pažymėtą paveikslą?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Šalinti pasirinktą paveikslą?

Yra išsaugotų žaidimų, kurie naudoja šį paveikslą. Šie žaidimai taip pat bus pašalinti.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bevardis</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Bevardis</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 dalių %2 %3% pabaigta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Ištrinti žaidimą</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Ištrinti pasirinktą žaidimą?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Apžvalga</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Pridėti žymę</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Šalinti žymę</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Nesužymėti</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Visi paveikslai</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Bevardis %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Šalinti pasirinktą žymę?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Atleiskite</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Žymė tokiu pavadinimu jau yra.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Atstatyti dalis</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Baigti</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Pasirinkti</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Rodinys</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Padidinti</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Sumažinti</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Geriausias pritaikymas</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Ro&amp;dyti apžvalgą</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Visas ekranas</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Išvaizda</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>Ka&amp;lba</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Valdymas</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Valdymas</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pakelti dalis:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Kairiojo mygtuko spustelėjimas arba Tarpas</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Nuleisti dalis:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pasirinkti dalis:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Vilkti, nuspaudus kairįjį mygtuką</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pasukti dalis:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Dešiniojo mygtuko spustelėjimas, Control + Kairiojo mygtuko spustelėjimas, arba R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Vilkti dėlionę:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Vidurinio mygtuko spustelėjimas, Shift + Kairiojo mygtuko spustelėjimas, arba Krypties klavišai</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Padidinti dėlionę:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Pelės ratukas arba +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Perkelti žymeklį:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Perkelti pele arba klavišais W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Apie Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Dėlionė su tetromino figūromis</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Autorių Teisės &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Pasirinkite OpenGL versiją.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>versija</translation>
    </message>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation>Paveikslai, kuriuos pridėti į žaidimo pasirinkimo dialogą.</translation>
    </message>
</context>
</TS>

==> tetzle_3.0.0.orig.tar.gz: tetzle-3.0.0/translations/tetzle_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Atverti paveikslą</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Paveikslai</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Išvaizda</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Parinktys</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Nuožulnūs kraštai</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Mesti šešėlius</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Spalvos</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fonas:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Šešėlis</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Paryškinimas:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Trūksta paveikslo.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Prašome palaukti</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Įkeliamas paveikslas...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Kuriama dėlionė...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Kuriamos dalys...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Įkeliama dėlionė...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Nežinomas duomenų formatas</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Nežinomas elementas &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>XML failo analizės klaida.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Įkeliamos dalys...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Gaunamos dalys...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Talpinamos dalys...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sėkmė</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Pasirinkite žaidimą</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Dabartiniai žaidimai</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Naujas žaidimas</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation>Žaisti žaidimą</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Paveikslo savybės</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Žymės:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation>Naujos žymės pavadinimas</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalbą:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos kalba&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Pridėti paveikslą</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Pašalinti paveikslą</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Paveikslo savybės</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 dalių</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Kopijuojami paveikslai...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atšaukti</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bevardis</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation>
            <numerusform>Šalinti pasirinktą paveikslą?</numerusform>
            <numerusform>Šalinti %n pasirinktus paveikslus?</numerusform>
            <numerusform>Šalinti %n pasirinktų paveikslų?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation>
            <numerusform>Įrašytas žaidimas, naudojantis šį paveikslą, bus ištrintas.</numerusform>
            <numerusform>Įrašyti žaidimai, naudojantis šiuos paveikslus, bus ištrinti.</numerusform>
            <numerusform>Įrašyti žaidimai, naudojantis šiuos paveikslus, bus ištrinti.</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Šalinti</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Bevardis</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 dalių %2 %3% pabaigta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Ištrinti žaidimą</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Ištrinti pasirinktą žaidimą?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Apžvalga</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Pridėti žymę</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Šalinti žymę</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Nesužymėti</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Visi paveikslai</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Bevardis %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Šalinti pasirinktą žymę?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Atleiskite</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Žymė tokiu pavadinimu jau yra.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation>Tvarkyti žymes...</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Atstatyti dalis</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Baigti</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Pasirinkti</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Rodinys</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Padidinti</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Sumažinti</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Geriausias pritaikymas</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Ro&amp;dyti apžvalgą</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Visas ekranas</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Išvaizda</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>Ka&amp;lba</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Valdymas</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Valdymas</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pakelti dalis:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Kairiojo mygtuko spustelėjimas arba Tarpas</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Nuleisti dalis:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pasirinkti dalis:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Vilkti, nuspaudus kairįjį mygtuką</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pasukti dalis:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Dešiniojo mygtuko spustelėjimas, Control + Kairiojo mygtuko spustelėjimas, arba R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Vilkti dėlionę:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Vidurinio mygtuko spustelėjimas, Shift + Kairiojo mygtuko spustelėjimas, arba Krypties klavišai</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Padidinti dėlionę:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Pelės ratukas arba +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Perkelti žymeklį:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Perkelti pele arba klavišais W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Apie Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Dėlionė su tetromino figūromis</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Autorių Teisės &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation>%p% užbaigta</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation>Mastelis: %1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation>Paveikslai, kuriuos pridėti į žaidimo pasirinkimo dialogą.</translation>
    </message>
</context>
</TS>
